@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -30,16 +30,16 @@ class MAILIMPORTER_EXPORT FilterClawsMail : public FilterSylpheed
 {
 public:
     FilterClawsMail();
-    ~FilterClawsMail();
+    ~FilterClawsMail() override;
 
-    static QString defaultSettingsPath();
-    static QString isMailerFound();
+    Q_REQUIRED_RESULT static QString defaultSettingsPath();
+    Q_REQUIRED_RESULT static QString isMailerFound();
 
     /* return local mail dir from folderlist.xml*/
-    QString localMailDirPath() override;
-    bool excludeFile(const QString &file) override;
-    QString defaultInstallFolder() const override;
-    QString markFile() const override;
+    Q_REQUIRED_RESULT QString localMailDirPath() override;
+    Q_REQUIRED_RESULT bool excludeFile(const QString &file) override;
+    Q_REQUIRED_RESULT QString defaultInstallFolder() const override;
+    Q_REQUIRED_RESULT QString markFile() const override;
 };
 }
 
